<?php

namespace Drupal\recurly_aegir\Provisioners;

use Drupal\recurly_aegir\Provisioners\RecurlyAegirSiteProvisioner;

/**
 * Base class for cloning new sites via Aegir's Web service API.
 */
class RecurlyAegirSiteCloneProvisioner extends RecurlyAegirSiteProvisioner {

  /**
   * The human-readable task type used by this privisioner.
   */
  const TASK_TYPE = 'Clone';

  /**
   * {@inheritdoc}
   */
  public static function getTaskType() {
    return self::TASK_TYPE;
  }

  /**
   * {@inheritdoc}
   *
   * Provisions new sites via clone tasks.
   */
  public function provision() {
    $client = \Drupal::httpClient();

    $data = [
      // Task type.
      'type' => strtolower($this->getTaskType()),
      // Source.
      'nid' => $this->template,
      // Destination.
      'options' => [
        'new_uri' => $this->hostname,
      ],
    ];

    try {
      $request = $client->post($this->endpoint, ['json' => $data]);
    }
    catch (Exception $e) {
      watchdog_exception('recurly_aegir', $e->getMessage());
    }

    // Set request results.
    $this->status = $request->getStatusCode();
    $this->headers = $request->getHeaders();
    $this->response = json_decode((string) $request->getBody(), TRUE);

    return $this;
  }

}
